==> nextcloud-27.1.5.tgz: nextcloud/apps/systemtags/l10n/uk.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Системну мітку %1$s додано системою",
    "Added system tag {systemtag}" : "Додано системну мітку {systemtag}",
    "Added system tag %1$s" : "Додано системну мітку %1$s",
    "%1$s added system tag %2$s" : "%1$s додав(-ла) системну мітку %2$s",
    "{actor} added system tag {systemtag}" : "{actor} додав(-ла) системну мітку {systemtag}",
    "System tag %1$s removed by the system" : "Системну мітку %1$s вилучено системою",
    "Removed system tag {systemtag}" : "Вилучено системну мітку {systemtag}",
    "Removed system tag %1$s" : "Вилучено системну мітку %1$s",
    "%1$s removed system tag %2$s" : "%1$s вилучив(-ла) системну мітку %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} вилучив системну мітку {systemtag}",
    "You created system tag %1$s" : "Ви створили системну мітку %1$s",
    "You created system tag {systemtag}" : "Ви створили системну мітку {systemtag}",
    "%1$s created system tag %2$s" : "%1$s створив(-ла) системну мітку %2$s ",
    "{actor} created system tag {systemtag}" : "{actor} створив(-ла) системну мітку {systemtag}",
    "You deleted system tag %1$s" : "Ви вилучили системну мітку %1$s",
    "You deleted system tag {systemtag}" : "Ви вилучили системну мітку {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s вилучена системна мітка %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} вилучив(-ла) системну мітку {systemtag}",
    "You updated system tag %2$s to %1$s" : "Ви оновили системну мітку %2$s до %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Ви оновили системну мітку {oldsystemtag} на {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s оновив(-ла) системну мітку %3$s до %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} оновив(-ла) системну мітку {oldsystemtag} на {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Системну мітку %2$s додано до %1$s системою",
    "System tag {systemtag} was added to {file} by the system" : "Системну мітку {systemtag} додано до {file} системою",
    "You added system tag %2$s to %1$s" : "Ви додали системну мітку %2$s до %1$s",
    "You added system tag {systemtag} to {file}" : "Ви додали системну мітку {systemtag} до {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s додав(-ла) системну мітку %3$s до %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} додав(-ла) системну мітку {systemtag} до {file}",
    "System tag %2$s was removed from %1$s by the system" : "Системну мітку %2$s вилучено системою з %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "Системну мітку {systemtag} вилучено системою з файлу {file}",
    "You removed system tag %2$s from %1$s" : "Ви вилучили системну мітку %2$s із %1$s",
    "You removed system tag {systemtag} from {file}" : "Ви вилучили системну мітку {systemtag} із {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s вилучено системну мітку %3$s з %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} вилучив системну мітку {systemtag} із {file}",
    "%s (restricted)" : "%s(обмежено)",
    "%s (invisible)" : "%s (невидимий)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Системні мітки</strong> для файлу було змінено",
    "Tags" : "Мітки",
    "All tagged %s …" : "Усі позначено мітками %s …",
    "tagged %s" : "позначено міткою %s",
    "Collaborative tags" : "Мітки для організації співпраці",
    "Collaborative tagging functionality which shares tags among users." : "Функція спільного додавання міток, яка дозволяж ділитися мітками між користувачами.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Функція спільного додавання міток, яка дозволяє ділитися мітками між користувачами. Чудово підходить для команд. \n(Якщо ви є провайдером із установкою з кількома клієнтами, радимо вимкнути цю програму, оскільки мітки є спільними.)",
    "Create or edit tags" : "Створити чи редагувати мітки",
    "Search for a tag to edit" : "Пошук мітки для редагування",
    "Collaborative tags …" : "Спільні мітки...",
    "No tags to select" : "Відсутні мітки для вибору",
    "Tag name" : "Назва мітки",
    "Tag level" : "Рівень мітки",
    "Create" : "Створити",
    "Update" : "Оновити",
    "Delete" : "Вилучити",
    "Reset" : "Скидання",
    "Loading …" : "Завантаження …",
    "Public" : "Публічна",
    "Restricted" : "Обмежена",
    "Invisible" : "Невидима",
    "Created tag" : "Створені мітки",
    "Failed to create tag" : "Не вдалося створити мітку",
    "Updated tag" : "Оновлені мітки",
    "Failed to update tag" : "Не вдалося оновити мітку",
    "Deleted tag" : "Видалена мітка",
    "Failed to delete tag" : "Не вдалося видалити мітку",
    "Loading collaborative tags …" : "Завантажую мітки співпрації...",
    "Search or create collaborative tags" : "Пошук або створення спільних міток",
    "No tags to select, type to create a new tag" : "Немає міток для вибору, почніть вводити, щоб додати нову мітку",
    "Failed to load tags" : "Не вдалося завантажити мітки",
    "Failed to load selected tags" : "Не вдалося завантажити вибрані мітки",
    "Failed to select tag" : "Не вдалося вибрати мітку",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Спільні мітки доступні для всіх користувачів. Заборонені мітки видимі для користувачів, але вони не можуть їх призначити. Невидимі мітки призначені для внутрішнього використання, оскільки користувачі не можуть бачити або призначати їх.",
    "This file has the tag {tag}" : "Цей файл має мітку {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Цей файл має мітку {firstTags} та {lastTag}",
    "List of tags and their associated files and folders." : "Перелік міток та файлів й каталогів, які їх мають",
    "No tags found" : "Відсутні мітки",
    "Tags you have created will show up here." : "Тут буде показано мітки, які було створено вами",
    "Failed to load last used tags" : "Не вдалося завантажити останні мітки",
    "Missing \"Content-Location\" header" : "Відсутній заголовок \"Content-Location\"",
    "Failed to load tags for file" : "Не вдалося завантажити мітки для файлу",
    "Failed to set tag for file" : "Не вдалося встановити мітку для файлу",
    "Failed to delete tag for file" : "Не вдалося видалити мітку для файлу",
    "No files in here" : "Тут немає файлів",
    "No entries found in this folder" : "В цьому каталозі нічого не знайдено",
    "Name" : "Ім’я",
    "Size" : "Розмір",
    "Modified" : "Змінено",
    "Tag name is empty" : "Назва мітки порожня",
    "Select tag …" : "Виберіть мітку…",
    "Tagged files" : "Файли з мітками",
    "Select tags to filter by" : "Фільтр вибору мітки за",
    "Please select tags to filter by" : "Виберіть мітки для подальшого фільтрування",
    "No files found for the selected tags" : "Не знайдено файлів з такими мітками",
    "Create a new tag" : "Додати нову мітку"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-27.1.7p0.tgz: nextcloud/apps/systemtags/l10n/uk.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Системну мітку %1$s додано системою",
    "Added system tag {systemtag}" : "Додано системну мітку {systemtag}",
    "Added system tag %1$s" : "Додано системну мітку %1$s",
    "%1$s added system tag %2$s" : "%1$s додав(-ла) системну мітку %2$s",
    "{actor} added system tag {systemtag}" : "{actor} додав(-ла) системну мітку {systemtag}",
    "System tag %1$s removed by the system" : "Системну мітку %1$s вилучено системою",
    "Removed system tag {systemtag}" : "Вилучено системну мітку {systemtag}",
    "Removed system tag %1$s" : "Вилучено системну мітку %1$s",
    "%1$s removed system tag %2$s" : "%1$s вилучив(-ла) системну мітку %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} вилучив системну мітку {systemtag}",
    "You created system tag %1$s" : "Ви створили системну мітку %1$s",
    "You created system tag {systemtag}" : "Ви створили системну мітку {systemtag}",
    "%1$s created system tag %2$s" : "%1$s створив(-ла) системну мітку %2$s ",
    "{actor} created system tag {systemtag}" : "{actor} створив(-ла) системну мітку {systemtag}",
    "You deleted system tag %1$s" : "Ви вилучили системну мітку %1$s",
    "You deleted system tag {systemtag}" : "Ви вилучили системну мітку {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s вилучена системна мітка %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} вилучив(-ла) системну мітку {systemtag}",
    "You updated system tag %2$s to %1$s" : "Ви оновили системну мітку %2$s до %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Ви оновили системну мітку {oldsystemtag} на {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s оновив(-ла) системну мітку %3$s до %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} оновив(-ла) системну мітку {oldsystemtag} на {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Системну мітку %2$s додано до %1$s системою",
    "System tag {systemtag} was added to {file} by the system" : "Системну мітку {systemtag} додано до {file} системою",
    "You added system tag %2$s to %1$s" : "Ви додали системну мітку %2$s до %1$s",
    "You added system tag {systemtag} to {file}" : "Ви додали системну мітку {systemtag} до {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s додав(-ла) системну мітку %3$s до %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} додав(-ла) системну мітку {systemtag} до {file}",
    "System tag %2$s was removed from %1$s by the system" : "Системну мітку %2$s вилучено системою з %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "Системну мітку {systemtag} вилучено системою з файлу {file}",
    "You removed system tag %2$s from %1$s" : "Ви вилучили системну мітку %2$s із %1$s",
    "You removed system tag {systemtag} from {file}" : "Ви вилучили системну мітку {systemtag} із {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s вилучено системну мітку %3$s з %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} вилучив системну мітку {systemtag} із {file}",
    "%s (restricted)" : "%s(обмежено)",
    "%s (invisible)" : "%s (невидимий)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Системні мітки</strong> для файлу було змінено",
    "Tags" : "Мітки",
    "All tagged %s …" : "Усі позначено мітками %s …",
    "tagged %s" : "позначено міткою %s",
    "Collaborative tags" : "Мітки для організації співпраці",
    "Create or edit tags" : "Створити чи редагувати мітки",
    "Search for a tag to edit" : "Пошук мітки для редагування",
    "Collaborative tags …" : "Спільні мітки...",
    "No tags to select" : "Відсутні мітки для вибору",
    "Tag name" : "Назва мітки",
    "Tag level" : "Рівень мітки",
    "Create" : "Створити",
    "Update" : "Оновити",
    "Delete" : "Вилучити",
    "Reset" : "Скидання",
    "Loading …" : "Завантаження …",
    "Public" : "Публічна",
    "Restricted" : "Обмежена",
    "Invisible" : "Невидима",
    "Created tag" : "Створені мітки",
    "Failed to create tag" : "Не вдалося створити мітку",
    "Updated tag" : "Оновлені мітки",
    "Failed to update tag" : "Не вдалося оновити мітку",
    "Deleted tag" : "Видалена мітка",
    "Failed to delete tag" : "Не вдалося вилучити мітку",
    "Loading collaborative tags …" : "Завантажую мітки співпрації...",
    "Search or create collaborative tags" : "Пошук або створення спільних міток",
    "No tags to select, type to create a new tag" : "Немає міток для вибору, почніть вводити, щоб додати нову мітку",
    "Failed to load tags" : "Не вдалося завантажити мітки",
    "Failed to load selected tags" : "Не вдалося завантажити вибрані мітки",
    "Failed to select tag" : "Не вдалося вибрати мітку",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Спільні мітки доступні для всіх користувачів. Заборонені мітки видимі для користувачів, але вони не можуть їх призначити. Невидимі мітки призначені для внутрішнього використання, оскільки користувачі не можуть бачити або призначати їх.",
    "This file has the tag {tag}" : "Цей файл має мітку {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Цей файл має мітку {firstTags} та {lastTag}",
    "List of tags and their associated files and folders." : "Перелік міток та файлів й каталогів, які їх мають",
    "No tags found" : "Відсутні мітки",
    "Tags you have created will show up here." : "Тут буде показано мітки, які було створено вами",
    "Failed to load last used tags" : "Не вдалося завантажити останні мітки",
    "Missing \"Content-Location\" header" : "Відсутній заголовок \"Content-Location\"",
    "Failed to load tags for file" : "Не вдалося завантажити мітки для файлу",
    "Failed to set tag for file" : "Не вдалося встановити мітку для файлу",
    "Failed to delete tag for file" : "Не вдалося вилучить мітку для файлу",
    "Tag name is empty" : "Назва мітки порожня",
    "Select tag …" : "Виберіть мітку…",
    "Collaborative tagging functionality which shares tags among users." : "Функція спільного додавання міток, яка дозволяж ділитися мітками між користувачами.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Функція спільного додавання міток, яка дозволяє ділитися мітками між користувачами. Чудово підходить для роботи в командах. \n(Якщо ви є постачальником посуг із встановленням для багатьох клієнтів, радимо вимкнути цей застосунок, оскільки мітки є спільними.)",
    "Tagged files" : "Файли з мітками",
    "Select tags to filter by" : "Фільтр вибору мітки за",
    "Please select tags to filter by" : "Виберіть мітки для подальшого фільтрування",
    "No files found for the selected tags" : "Не знайдено файлів з такими мітками",
    "Create a new tag" : "Додати нову мітку",
    "Name" : "Ім’я",
    "No files in here" : "Тут немає файлів",
    "No entries found in this folder" : "В цьому каталозі нічого не знайдено",
    "Size" : "Розмір",
    "Modified" : "Змінено"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
